/****************************************************************************
**
** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
** Copyright (c) 2007 Martin Teichmann. All rights reserved.
**
** This file is part of the KAD project, based on a file
** from the qcadlib Library project.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
**********************************************************************/

#ifndef QG_ACTIONHANDLER_H
#define QG_ACTIONHANDLER_H

#include <kactionclasses.h>
#include <qmainwindow.h>
#include <qobject.h>

#include "rs_document.h"
#include "rs_stringlist.h"

#include "qg_graphicview.h"

class QG_MainWindowInterface;
class QG_CadToolBarSnap;
class QG_CadToolBarSelect;



/**
 * This class can trigger actions (from menus, buttons, ...).
 */
class QG_ActionHandler : public QObject {
    Q_OBJECT

public:
    QG_ActionHandler(QG_MainWindowInterface* mw);
    virtual ~QG_ActionHandler();

	RS_ActionInterface* getCurrentAction();
    RS_ActionInterface* setCurrentAction(RS2::ActionType id);
	void killSelectActions();
	
	bool keycode(const QString& code);
	bool command(const QString& cmd);
	RS_StringList getAvailableCommands();

public slots:
    /*void slotFileNew();*/
    void slotFileOpen();
    /*
          void slotFileOpen(const QString& fileName);
          void slotFileSave();
     */
    void slotFileSaveAs();
    /*
         void slotFileClose();
         void slotFilePrint();
      */

    void slotZoomIn();
    void slotZoomOut();
    void slotZoomAuto();
    void slotZoomWindow();
    void slotZoomPan();
    void slotZoomPrevious();
    void slotZoomRedraw();

	void slotToolRegenerateDimensions();

    void slotEditUndo();
    void slotEditRedo();
    void slotEditCut();
    void slotEditCopy();
    void slotEditPaste();

    void slotSelectSingle();
    void slotSelectContour();
    void slotSelectWindow();
    void slotDeselectWindow();
    void slotSelectAll();
    void slotDeselectAll();
    void slotSelectInvert();
    void slotSelectIntersected();
    void slotDeselectIntersected();
    void slotSelectLayer();

    void slotDrawPoint();
    void slotDrawLine();
    void slotDrawLineAngle();
    void slotDrawLineHorizontal();
    void slotDrawLineVertical();
    void slotDrawLineFree();
    void slotDrawLineHorVert();
    void slotDrawLineParallel();
    void slotDrawLineParallelThrough();
    void slotDrawLineRectangle();
    void slotDrawLineBisector();
    void slotDrawLineTangent1();
    void slotDrawLineTangent2();
    void slotDrawLineOrthogonal();
    void slotDrawLineRelAngle();
    void slotDrawLinePolygon();
    void slotDrawLinePolygon2();
    void slotDrawCircle();
    void slotDrawCircleCR();
    void slotDrawCircle2P();
    void slotDrawCircle3P();
    void slotDrawCircleParallel();
    void slotDrawArc();
    void slotDrawArc3P();
    void slotDrawArcParallel();
    void slotDrawArcTangential();
    void slotDrawEllipseAxis();
    void slotDrawEllipseArcAxis();
    void slotDrawSpline();
    void slotDrawText();
    void slotDrawHatch();
    void slotDrawImage();
    void slotDrawPolyline();
    void slotPolylineAdd();
    void slotPolylineAppend();
    void slotPolylineDel();
    void slotPolylineDelBetween();
    void slotPolylineTrim();

    void slotDimAligned();
    void slotDimLinear();
    void slotDimLinearHor();
    void slotDimLinearVer();
    void slotDimRadial();
    void slotDimDiametric();
    void slotDimAngular();
    void slotDimLeader();

    void slotModifyAttributes();
    void slotModifyDelete();
    void slotModifyDeleteQuick();
    void slotModifyDeleteFree();
    void slotModifyMove();
    void slotModifyScale();
    void slotModifyRotate();
    void slotModifyMirror();
    void slotModifyMoveRotate();
    void slotModifyRotate2();
    void slotModifyEntity();
    void slotModifyTrim();
    void slotModifyTrim2();
    void slotModifyTrimAmount();
    void slotModifyCut();
    void slotModifyStretch();
    void slotModifyBevel();
    void slotModifyRound();
    void slotModifyExplodeText();

    void slotSnapFree();
    void slotSnapGrid();
    void slotSnapEndpoint();
    void slotSnapOnEntity();
    void slotSnapCenter();
    void slotSnapMiddle();
    void slotSnapDist();
    void slotSnapIntersection();
    void slotSnapIntersectionManual();
    
    void slotRestrictNothing();
    void slotRestrictOrthogonal();
    void slotRestrictHorizontal();
    void slotRestrictVertical();

    void disableSnaps();
    void disableRestrictions();
    void updateSnapMode();

    void slotSetRelativeZero();
    void slotLockRelativeZero(bool on);
    
    void slotInfoInside();
    void slotInfoDist();
    void slotInfoDist2();
    void slotInfoAngle();
    void slotInfoTotalLength();
    void slotInfoArea();

    void slotLayersDefreezeAll();
    void slotLayersFreezeAll();
    void slotLayersAdd();
    void slotLayersRemove();
    void slotLayersEdit();
    void slotLayersToggleView();
    void slotLayersToggleLock();

    void slotBlocksDefreezeAll();
    void slotBlocksFreezeAll();
    void slotBlocksAdd();
    void slotBlocksRemove();
    void slotBlocksAttributes();
    void slotBlocksEdit();
    void slotBlocksInsert();
    void slotBlocksToggleView();
    void slotBlocksCreate();
    void slotBlocksExplode();
	
    void slotOptionsDrawing();
	
	void slotCamExportAuto();
	void slotCamReorder();

	void slotFocusNormal();

    void setActionSnapFree(KToggleAction* a) {
        snapFree = a;
    }
    void setActionSnapGrid(KToggleAction* a) {
        snapGrid = a;
    }
    void setActionSnapEndpoint(KToggleAction* a) {
        snapEndpoint = a;
    }
    void setActionSnapOnEntity(KToggleAction* a) {
        snapOnEntity = a;
    }
    void setActionSnapCenter(KToggleAction* a) {
        snapCenter = a;
    }
    void setActionSnapMiddle(KToggleAction* a) {
        snapMiddle = a;
    }
    void setActionSnapDist(KToggleAction* a) {
        snapDist = a;
    }
    void setActionSnapIntersection(KToggleAction* a) {
        snapIntersection = a;
    }
    void setActionSnapIntersectionManual(KToggleAction* a) {
        snapIntersectionManual = a;
    }
    void setActionRestrictNothing(KToggleAction* a) {
        restrictNothing = a;
    }
    void setActionRestrictOrthogonal(KToggleAction* a) {
        restrictOrthogonal = a;
    }
    void setActionRestrictHorizontal(KToggleAction* a) {
        restrictHorizontal = a;
    }
    void setActionRestrictVertical(KToggleAction* a) {
        restrictVertical = a;
    }
    void setActionLockRelativeZero(KToggleAction* a) {
        lockRelativeZero = a;
    }

    void setCadToolBarSnap(QG_CadToolBarSnap* tb);

private:
    QG_MainWindowInterface* mainWindow;
    QG_CadToolBarSnap* cadToolBarSnap;

    KToggleAction* snapFree;
    KToggleAction* snapGrid;
    KToggleAction* snapEndpoint;
    KToggleAction* snapOnEntity;
    KToggleAction* snapCenter;
    KToggleAction* snapMiddle;
    KToggleAction* snapDist;
    KToggleAction* snapIntersection;
    KToggleAction* snapIntersectionManual;
    
    KToggleAction* restrictNothing;
    KToggleAction* restrictOrthogonal;
    KToggleAction* restrictHorizontal;
    KToggleAction* restrictVertical;
    
    KToggleAction* lockRelativeZero;
};

#endif

// EOF
