/****************************************************************************
**
** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
** Copyright (c) 2007 Martin Teichmann. All rights reserved.
**
** This file is part of the KAD project, based on a file
** from the qcadlib Library project.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
**********************************************************************/

#include "qg_pentoolbar.h"
#include <ktoolbar.h>
#include <klocale.h>

/**
 * Constructor.
 */
QG_PenToolBar::QG_PenToolBar(QWidget *p, KActionCollection *ac)
        : KAction(i18n("Pen Tools"), 0, parent, 0, ac, "pen_tools"),
	  parent(p)
{ }

int QG_PenToolBar::plug(QWidget *w, int index)
{
    KToolBar *toolbar;

    if (!(toolbar = dynamic_cast<KToolBar *>(w))) return 0;

    colorBox = new QG_ColorBox(true, false, toolbar, "colorbox");
    colorBox->setMinimumWidth(80);
    connect(colorBox, SIGNAL(colorChanged(const RS_Color&)),
            this, SLOT(slotColorChanged(const RS_Color&)));

    widthBox = new QG_WidthBox(true, false, toolbar, "widthbox");
    widthBox->setMinimumWidth(80);
    connect(widthBox, SIGNAL(widthChanged(RS2::LineWidth)),
            this, SLOT(slotWidthChanged(RS2::LineWidth)));

    lineTypeBox = new QG_LineTypeBox(true, false, toolbar, "lineTypebox");
    lineTypeBox->setMinimumWidth(80);
    connect(lineTypeBox, SIGNAL(lineTypeChanged(RS2::LineType)),
            this, SLOT(slotLineTypeChanged(RS2::LineType)));

    currentPen.setColor(colorBox->getColor());
    currentPen.setWidth(widthBox->getWidth());
    currentPen.setLineType(lineTypeBox->getLineType());
}


/**
 * Destructor
 */
QG_PenToolBar::~QG_PenToolBar() {}


/**
 * Called by the layer list if this object was added as a listener 
 * to a layer list.
 */
void QG_PenToolBar::layerActivated(RS_Layer* l)
{
    if (!l) return;

    if (colorBox) colorBox->setLayerColor(l->getPen().getColor());
    if (widthBox) widthBox->setLayerWidth(l->getPen().getWidth());
    if (lineTypeBox) lineTypeBox->setLayerLineType(l->getPen().getLineType());
}


/**
 * Called by the layer list (if this object was previously 
 * added as a listener to a layer list).
 */
void QG_PenToolBar::layerEdited(RS_Layer*) {}


/**
 * Called when the color was changed by the user.
 */
void QG_PenToolBar::slotColorChanged(const RS_Color& color) {
    currentPen.setColor(color);
    emit penChanged(currentPen);
}

/**
 * Called when the width was changed by the user.
 */
void QG_PenToolBar::slotWidthChanged(RS2::LineWidth w) {
    currentPen.setWidth(w);
    emit penChanged(currentPen);
}

/**
 * Called when the linetype was changed by the user.
 */
void QG_PenToolBar::slotLineTypeChanged(RS2::LineType w) {
    currentPen.setLineType(w);
    emit penChanged(currentPen);
}

#include "qg_pentoolbar.moc"
