/****************************************************************************
**
** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
** Copyright (c) 2007 Martin Teichmann. All rights reserved.
**
** This file is part of the KAD project, based on a file from
** the qcadlib Library project.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
**********************************************************************/

#ifndef QG_PENTOOLBAR_H
#define QG_PENTOOLBAR_H

#include <qtoolbar.h>
#include <kaction.h>

#include "rs_layerlistlistener.h"
#include "rs_pen.h"

#include "qg_colorbox.h"
#include "qg_widthbox.h"
#include "qg_linetypebox.h"

/**
 * A toolbar that offers all widgets for choosing a pen.
 */
class QG_PenToolBar: public KAction,
    public RS_LayerListListener {
    Q_OBJECT

public:
    QG_PenToolBar(QWidget *, KActionCollection *);
    virtual ~QG_PenToolBar();

    virtual int plug(QWidget *, int = -1);

    RS_Pen getPen() {
        return currentPen;
    }

    // Methods from RS_LayerListListener Interface:
    virtual void layerActivated(RS_Layer*);
    virtual void layerEdited(RS_Layer*);

public slots:
    void slotColorChanged(const RS_Color& color);
    void slotWidthChanged(RS2::LineWidth w);
    void slotLineTypeChanged(RS2::LineType w);

signals:
    void penChanged(RS_Pen);

private:
    RS_Pen currentPen;
    QG_ColorBox* colorBox;
    QG_WidthBox* widthBox;
    QG_LineTypeBox* lineTypeBox;
    QWidget *parent;
};

#endif

